let
  sources = import ./nix/sources.nix;
  pkgs = import sources.nixpkgs { };
  nur = import (builtins.fetchTarball
    "https://github.com/nix-community/NUR/archive/master.tar.gz") {
      inherit pkgs;
    };
  dhall = pkgs.callPackage ./nix/dhall.nix { };
  dhall-json = pkgs.callPackage ./nix/dhall-json.nix { };
  dyson = pkgs.callPackage ./nix/dyson.nix { };
  tex = pkgs.callPackage ./nix/texlive.nix { };
in pkgs.mkShell {
  buildInputs = with pkgs; [
    # deployment tools
    dyson
    kubectl
    kubectx

    # book tools
    kindlegen
    mdbook
    nur.repos.mic92.pandoc-bin
    tex

    # preview
    nur.repos.xe.zathura

    # dhall
    dhall
    dhall-json

    # deno
    nur.repos.xe.deno
    nodePackages.typescript
    nodePackages.typescript-language-server

    # rust
    cargo
    cargo-watch
    rls
    rustc
    rustfmt
  ];
}
